@@ -28,7 +28,7 @@ fi
 
 if [ -n "$(git status --porcelain)" ]; then
     echo ". is not clean." >&2
-#    exit 1
+    exit 1
 fi
 
 perl -pi -e "s/(?<=AC_INIT\(\[GeoIP\], \[)(\d+\.\d+\.\d+)(?=])/$version/gsm" configure.ac
@@ -54,10 +54,6 @@ fi
 
 git push
 
-popd
-
-git push
-
 message="$version
 
 $notes"
