@@ -15,19 +15,15 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
 #include "GeoIP.h"
 #include "GeoIPCity.h"
 
-static const char *_mk_NA(const char *p)
-{
-    return p ? p : "N/A";
-}
+static const char *_mk_NA(const char *p) { return p ? p : "N/A"; }
 
-int main(int argc, char *argv[])
-{
+int main(int argc, char *argv[]) {
     FILE *f;
     GeoIP *gi;
     GeoIPRecord *gir;
@@ -54,16 +50,22 @@ int main(int argc, char *argv[])
 
         if (gir != NULL) {
             ret = GeoIP_range_by_ip(gi, (const char *)host);
-            time_zone =
-                GeoIP_time_zone_by_country_and_region(gir->country_code,
-                                                      gir->region);
-            printf("%s\t%s\t%s\t%s\t%s\t%s\t%f\t%f\t%d\t%d\t%s\t%s\t%s\n", host,
-                   _mk_NA(gir->country_code), _mk_NA(gir->region),
-                   _mk_NA(GeoIP_region_name_by_code
-                              (gir->country_code,
-                              gir->region)), _mk_NA(gir->city),
-                   _mk_NA(gir->postal_code), gir->latitude, gir->longitude,
-                   gir->metro_code, gir->area_code, _mk_NA(time_zone), ret[0],
+            time_zone = GeoIP_time_zone_by_country_and_region(gir->country_code,
+                                                              gir->region);
+            printf("%s\t%s\t%s\t%s\t%s\t%s\t%f\t%f\t%d\t%d\t%s\t%s\t%s\n",
+                   host,
+                   _mk_NA(gir->country_code),
+                   _mk_NA(gir->region),
+                   _mk_NA(GeoIP_region_name_by_code(gir->country_code,
+                                                    gir->region)),
+                   _mk_NA(gir->city),
+                   _mk_NA(gir->postal_code),
+                   gir->latitude,
+                   gir->longitude,
+                   gir->metro_code,
+                   gir->area_code,
+                   _mk_NA(time_zone),
+                   ret[0],
                    ret[1]);
             GeoIP_range_by_ip_delete(ret);
             GeoIPRecord_delete(gir);
