@@ -15,13 +15,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
 #include "GeoIP.h"
 
-int main()
-{
+int main(void) {
     FILE *f;
     char *db_info;
     char ipAddress[30];
@@ -49,7 +48,9 @@ int main()
         }
 
         db_info = GeoIP_database_info(gi);
-        if (!db_info || !strstr(db_info, " Copyright")) {
+        if (!db_info || strcmp(db_info,
+                               "GEO-106 20160621 Build 1 Copyright (c) 2016 "
+                               "MaxMind Inc All Rights Reserved")) {
             fprintf(stderr, "Error reading database info (got %s).\n", db_info);
             free(db_info);
             failed = 1;
@@ -72,38 +73,51 @@ int main()
 
         f = fopen(SRCDIR "/test/country_test.txt", "r");
 
-        while (fscanf(f, "%s%s%s", ipAddress, expectedCountry, expectedCountry3)
-               != EOF) {
+        while (
+            fscanf(f, "%s%s%s", ipAddress, expectedCountry, expectedCountry3) !=
+            EOF) {
             returnedCountry = GeoIP_country_code_by_addr(gi, ipAddress);
-            if (returnedCountry == NULL
-                || strcmp(returnedCountry, expectedCountry) != 0) {
+            if (returnedCountry == NULL ||
+                strcmp(returnedCountry, expectedCountry) != 0) {
                 fprintf(stderr,
                         "Test addr %d for %s failed, got %s, expected %s\n",
-                        test_num, ipAddress, returnedCountry, expectedCountry);
+                        test_num,
+                        ipAddress,
+                        returnedCountry,
+                        expectedCountry);
                 failed = 1;
             }
             returnedCountry = GeoIP_country_code_by_name(gi, ipAddress);
-            if (returnedCountry == NULL
-                || strcmp(returnedCountry, expectedCountry) != 0) {
+            if (returnedCountry == NULL ||
+                strcmp(returnedCountry, expectedCountry) != 0) {
                 fprintf(stderr,
                         "Test name %d for %s failed, got %s, expected %s\n",
-                        test_num, ipAddress, returnedCountry, expectedCountry);
+                        test_num,
+                        ipAddress,
+                        returnedCountry,
+                        expectedCountry);
                 failed = 1;
             }
             returnedCountry = GeoIP_country_code3_by_addr(gi, ipAddress);
-            if (returnedCountry == NULL
-                || strcmp(returnedCountry, expectedCountry3) != 0) {
+            if (returnedCountry == NULL ||
+                strcmp(returnedCountry, expectedCountry3) != 0) {
                 fprintf(stderr,
                         "Test addr %d for %s failed, got %s, expected %s\n",
-                        test_num, ipAddress, returnedCountry, expectedCountry);
+                        test_num,
+                        ipAddress,
+                        returnedCountry,
+                        expectedCountry);
                 failed = 1;
             }
             returnedCountry = GeoIP_country_code3_by_name(gi, ipAddress);
-            if (returnedCountry == NULL
-                || strcmp(returnedCountry, expectedCountry3) != 0) {
+            if (returnedCountry == NULL ||
+                strcmp(returnedCountry, expectedCountry3) != 0) {
                 fprintf(stderr,
                         "Test name %d for %s failed, got %s, expected %s\n",
-                        test_num, ipAddress, returnedCountry, expectedCountry);
+                        test_num,
+                        ipAddress,
+                        returnedCountry,
+                        expectedCountry);
                 failed = 1;
             }
             test_num++;
@@ -113,28 +127,18 @@ int main()
         f = fopen(SRCDIR "/test/country_test2.txt", "r");
         while (fscanf(f, "%s%s", ipAddress, expectedCountry) != EOF) {
             returnedCountry = GeoIP_country_code_by_addr(gi, ipAddress);
-            if (returnedCountry == NULL
-                || strcmp(returnedCountry, expectedCountry) != 0) {
-                fprintf(stderr, "Test addr %d %s failed, got %s, expected %s\n",
-                        test_num, ipAddress, returnedCountry, expectedCountry);
+            if (returnedCountry == NULL ||
+                strcmp(returnedCountry, expectedCountry) != 0) {
+                fprintf(stderr,
+                        "Test addr %d %s failed, got %s, expected %s\n",
+                        test_num,
+                        ipAddress,
+                        returnedCountry,
+                        expectedCountry);
                 failed = 1;
             }
             test_num++;
         }
-        fclose(f);
-
-        f = fopen(SRCDIR "/test/country_test_name.txt", "r");
-        while (fscanf(f, "%s%s", ipAddress, expectedCountry) != EOF) {
-            returnedCountry = GeoIP_country_code_by_name(gi, ipAddress);
-            if (returnedCountry == NULL
-                || strcmp(returnedCountry, expectedCountry) != 0) {
-                fprintf(stderr, "Test addr %d %s failed, got %s, expected %s\n",
-                        test_num, ipAddress, returnedCountry, expectedCountry);
-                failed = 1;
-            }
-            test_num++;
-        }
-
         fclose(f);
         GeoIP_delete(gi);
     }
